@@ -46,6 +46,12 @@ while (defined($_ = shift @data)) {
 	$try .= "\$x / \$y;";
       } elsif ($f eq bmod) {
 	$try .= "\$x % \$y;";
+      } elsif ($f eq bdiv2a) {
+	$try .= "((Math::GMP::bdiv(\$x, \$y))[0]);";
+      } elsif ($f eq bdiv2b) {
+	$try .= "((Math::GMP::bdiv(\$x, \$y))[1]);";
+      } elsif ($f eq 'bgcd') {
+	$try .= "Math::GMP::bgcd(\$x, \$y);";
       } elsif ($f eq 'gcd') {
 	$try .= "Math::GMP::gcd(\$x, \$y);";
       } elsif ($f eq 'new_from_base') {
@@ -220,6 +226,39 @@ i9:+11111111111:99999999999
 +77777777777:9:699999999993
 +88888888888:9:799999999992
 +99999999999:9:899999999991
+&bdiv2a
++0:1:0
++0:-1:0
++1:1:1
+-1:-1:1
++1:-1:-1
+-1:1:-1
++1:2:0
++2:1:2
++1000000000:9:111111111
++1000000000:i9:111111111
++2000000000:9:222222222
++3000000000:9:333333333
++4000000000:9:444444444
++5000000000:9:555555555
++6000000000:9:666666666
++7000000000:9:777777777
++8000000000:9:888888888
++9000000000:9:1000000000
++35500000:113:314159
++71000000:226:314159
++106500000:339:314159
++1000000000:3:333333333
++10:5:2
++100:4:25
++1000:8:125
++10000:16:625
+i+10000:16:625
++999999999999:9:111111111111
++999999999999:99:10101010101
++999999999999:999:1001001001
++999999999999:9999:100010001
++999999999999999:99999:10000100001
 &bdiv
 +0:1:0
 +0:-1:0
@@ -253,6 +292,39 @@ i+10000:16:625
 +999999999999:999:1001001001
 +999999999999:9999:100010001
 +999999999999999:99999:10000100001
+&bdiv2b
++0:1:0
++0:-1:0
++1:1:0
+-1:-1:0
++1:-1:0
+-1:1:0
++1:2:1
++2:1:0
++1000000000:9:1
++1000000000:i9:1
++2000000000:9:2
++3000000000:9:3
++4000000000:9:4
++5000000000:9:5
++6000000000:9:6
++7000000000:9:7
++8000000000:9:8
++9000000000:9:0
++35500000:113:33
+i+35500000:113:33
++71000000:226:66
++106500000:339:99
++1000000000:3:1
++10:5:0
++100:4:0
++1000:8:0
++10000:16:0
++999999999999:9:0
++999999999999:99:0
++999999999999:999:0
++999999999999:9999:0
++999999999999999:99999:0
 &bmod
 +0:1:0
 +0:-1:0
@@ -286,6 +358,15 @@ i+35500000:113:33
 +999999999999:999:0
 +999999999999:9999:0
 +999999999999999:99999:0
+&bgcd
++0:0:0
++0:1:1
++1:0:1
++1:1:1
++2:3:1
++3:2:1
++100:625:25
++4096:81:1
 &gcd
 +0:0:0
 +0:1:1
